Enumeration
GimpExportReturn
since: 3.0
Members
GIMP_EXPORT_IGNORE-
The image is unmodified but export shall continue anyway.
- Value:
0 - Nickname:
None - Available since: 3.0
- Value:
GIMP_EXPORT_EXPORT-
The chosen transforms were applied to a new image.
- Value:
1 - Nickname:
None - Available since: 3.0
- Value: